Unavailable

Struct Unavailable 

pub struct Unavailable { /* private fields */ }
A placeholder for a missing Transmit or Receive end of a connection.

When using split, the resultant two channels can only send or only receive, respectively. This is reflected at the type level by the presence of Unavailable on the type of the connection which is not present for each part of the split.