#[repr(transparent)]pub struct Send<T, P>(pub PhantomData<T>, pub P);Expand description
Send a message of type T using send, then continue with
protocol P.
Tuple Fields
0: PhantomData<T>1: PTrait Implementations
Sourceimpl<T: 'static, P: 'static> Actionable for Send<T, P>
impl<T: 'static, P: 'static> Actionable for Send<T, P>
Sourceimpl<T: Any, P: HasDual> HasDual for Send<T, P>
impl<T: Any, P: HasDual> HasDual for Send<T, P>
Sourcetype DualSession = Recv<T, <P as HasDual>::DualSession>
type DualSession = Recv<T, <P as HasDual>::DualSession>
The dual to this session type, i.e. the session type required of the other end of the
channel.
Sourceimpl<T: Ord, P: Ord> Ord for Send<T, P>
impl<T: Ord, P: Ord> Ord for Send<T, P>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialOrd, P: PartialOrd> PartialOrd for Send<T, P>
impl<T: PartialOrd, P: PartialOrd> PartialOrd for Send<T, P>
Sourceimpl<N: Unary, T: 'static, P: Subst<Q, N>, Q> Subst<Q, N> for Send<T, P>
impl<N: Unary, T: 'static, P: Subst<Q, N>, Q> Subst<Q, N> for Send<T, P>
Sourcetype Substituted = Send<T, <P as Subst<Q, N>>::Substituted>
type Substituted = Send<T, <P as Subst<Q, N>>::Substituted>
The result of the substitution.
impl<T: Copy, P: Copy> Copy for Send<T, P>
impl<T: Eq, P: Eq> Eq for Send<T, P>
impl<T: 'static, N: Unary, P: Scoped<N>> Scoped<N> for Send<T, P>
impl<T, P> StructuralPartialEq for Send<T, P>