pub struct Split<P, Q, R>(pub P, pub Q, pub R);Expand description
Tuple Fields
0: P1: Q2: RTrait Implementations
Sourceimpl<P: 'static, Q: 'static, R: 'static> Actionable for Split<P, Q, R>
impl<P: 'static, Q: 'static, R: 'static> Actionable for Split<P, Q, R>
Sourceimpl<P: HasDual, Q: HasDual, R: HasDual> HasDual for Split<P, Q, R>
impl<P: HasDual, Q: HasDual, R: HasDual> HasDual for Split<P, Q, R>
Sourcetype DualSession = Split<<Q as HasDual>::DualSession, <P as HasDual>::DualSession, <R as HasDual>::DualSession>
type DualSession = Split<<Q as HasDual>::DualSession, <P as HasDual>::DualSession, <R as HasDual>::DualSession>
Note how the dual flips the position of P and Q, because P::Dual is a receiving
session, and therefore belongs on the right of the split, and Q::Dual is a sending
session, and therefore belongs on the left of the split.
Sourceimpl<N: Unary, Level: Unary, P: Lift<N, Level>, Q: Lift<N, Level>, R: Lift<N, Level>> Lift<N, Level> for Split<P, Q, R>
impl<N: Unary, Level: Unary, P: Lift<N, Level>, Q: Lift<N, Level>, R: Lift<N, Level>> Lift<N, Level> for Split<P, Q, R>
Sourceimpl<P: Ord, Q: Ord, R: Ord> Ord for Split<P, Q, R>
impl<P: Ord, Q: Ord, R: Ord> Ord for Split<P, Q, R>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<P: PartialOrd, Q: PartialOrd, R: PartialOrd> PartialOrd for Split<P, Q, R>
impl<P: PartialOrd, Q: PartialOrd, R: PartialOrd> PartialOrd for Split<P, Q, R>
Sourceimpl<N: Unary, P: Subst<S, N>, Q: Subst<S, N>, R: Subst<S, N>, S> Subst<S, N> for Split<P, Q, R>
impl<N: Unary, P: Subst<S, N>, Q: Subst<S, N>, R: Subst<S, N>, S> Subst<S, N> for Split<P, Q, R>
Sourcetype Substituted = Split<<P as Subst<S, N>>::Substituted, <Q as Subst<S, N>>::Substituted, <R as Subst<S, N>>::Substituted>
type Substituted = Split<<P as Subst<S, N>>::Substituted, <Q as Subst<S, N>>::Substituted, <R as Subst<S, N>>::Substituted>
The result of the substitution.
impl<P: Copy, Q: Copy, R: Copy> Copy for Split<P, Q, R>
impl<P: Eq, Q: Eq, R: Eq> Eq for Split<P, Q, R>
impl<N: Unary, P: Scoped<N>, Q: Scoped<N>, R: Scoped<N>> Scoped<N> for Split<P, Q, R>
impl<P, Q, R> StructuralPartialEq for Split<P, Q, R>